/*
  Copyright (C) 2003  Taiga Yonekura, taiga@col.hi-ho.ne.jp

  For more information about this appliation please look at:
   http://www.pat.hi-ho.ne.jp/kyonekura

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#ifndef MAINWIN_H
#define MAINWIN_H

#ifdef DESKTOP
#include <qmenubar.h>
#else
#include <qpe/qpemenubar.h>
#endif
#include <qmainwindow.h>
#include <qpopupmenu.h>
#include "gameWidget.h"

class CMainWin : public QMainWindow
{
    Q_OBJECT

public:
    CMainWin(QWidget *parent = 0, const char *name = 0, WFlags f = 0);

private:


private:
    CGameWidget *m_game;

protected:
    void closeEvent ( QCloseEvent *e );
    void setupLang();


protected slots:

};

#endif

